@@ -1,5 +1,5 @@
 use arrow::json::ReaderBuilder;
-use clap::{Clap, ValueHint};
+use clap::{Parser, ValueHint};
 use parquet::{
     arrow::ArrowWriter,
     basic::{Compression, Encoding},
@@ -10,7 +10,7 @@ use serde_json::to_string_pretty;
 use std::fs::File;
 use std::path::PathBuf;
 
-#[derive(clap::ArgEnum)]
+#[derive(clap::ArgEnum, Clone)]
 #[allow(non_camel_case_types, clippy::upper_case_acronyms)]
 enum ParquetCompression {
     UNCOMPRESSED,
@@ -22,7 +22,7 @@ enum ParquetCompression {
     ZSTD,
 }
 
-#[derive(clap::ArgEnum)]
+#[derive(clap::ArgEnum, Clone)]
 #[allow(non_camel_case_types, clippy::upper_case_acronyms)]
 enum ParquetEncoding {
     PLAIN,
@@ -34,7 +34,7 @@ enum ParquetEncoding {
     RLE_DICTIONARY,
 }
 
-#[derive(Clap)]
+#[derive(Parser)]
 #[clap(version = env!("CARGO_PKG_VERSION"), author = "Dominik Moritz <domoritz@cmu.edu>")]
 struct Opts {
     /// Input JSON file.
@@ -45,7 +45,7 @@ struct Opts {
     #[clap(name = "PARQUET", parse(from_os_str), value_hint = ValueHint::AnyPath)]
     output: PathBuf,
 
-    /// The number of records to infer the schema from. All rows if not present.
+    /// The number of records to infer the schema from. All rows if not present. Setting max-read-records to zero will stop schema inference and all columns will be string typed.
     #[clap(long)]
     max_read_records: Option<usize>,
 
